==> private_message_queue-8.x-1.3.tar.gz: private_message_queue/src/Plugin/QueueWorker/PrivateMessageQueueWorker.php <==
<?php

namespace Drupal\private_message_queue\Plugin\QueueWorker;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\Core\Session\AccountInterface;
use Drupal\private_message\Entity\PrivateMessage;
use Drupal\private_message\Entity\PrivateMessageInterface;
use Drupal\private_message\Service\PrivateMessageServiceInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes queued private message threads.
 *
 * @QueueWorker(
 *   id = "private_message_queue",
 *   title = @Translation("Queue for creating private message threads."),
 *   cron = {"time" = 60}
 * )
 */
class PrivateMessageQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
   * The private message service.
   *
   * @var \Drupal\private_message\Service\PrivateMessageServiceInterface
   */
  private $privateMessage;

  /**
   * Creates a new \Drupal\private_message_queue\Plugin\QueueWorker\PrivateMessageThreadQueue.
   *
   * @param array $configuration
   *  A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\private_message\Service\PrivateMessageServiceInterface $private_message_service
   *   The private message service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, PrivateMessageServiceInterface $private_message_service) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->privateMessage = $private_message_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('private_message.service')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data) {
    $message = $this->createMessage($data['owner'], $data['message']);

    $this->createThread($message, $data['recipients'], $data['owner']);
  }

  /**
   * Create a new private message.
   *
   * @param \Drupal\Core\Session\AccountInterface $owner
   *   The message owner.
   * @param string $message_body
   *   The message body.
   * @param string $text_format
   *   (optional) The text format. Defaults to 'basic_html'.
   *
   * @return \Drupal\Core\Entity\EntityInterface|\Drupal\private_message\Entity\PrivateMessage
   *   The created message.
   */
  private function createMessage(AccountInterface $owner, $message_body, $text_format = 'basic_html') {
    $message = PrivateMessage::create();
    $message->setOwnerId($owner->id());
    $message->set('message', ['value' => strip_tags($message_body), 'format' => $text_format]);
    $message->save();

    return $message;
  }

  /**
   * Create a private message thread.
   *
   * @param \Drupal\private_message\Entity\PrivateMessageInterface $message
   *   A message to add.
   * @param \Drupal\user\UserInterface[] $recipients
   *   The message recipients.
   * @param \Drupal\Core\Session\AccountInterface $owner
   *   The message owner.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  private function createThread(PrivateMessageInterface $message, array $recipients, AccountInterface $owner) {
    /** @var \Drupal\private_message\Entity\PrivateMessageThreadInterface $thread */
    $thread = $this->privateMessage->getThreadForMembers($recipients);
    $thread->addMemberById($owner->id());
    $thread->addMessage($message);
    $thread->save();
  }

}

==> private_message_queue-8.x-1.4.tar.gz: private_message_queue/src/Plugin/QueueWorker/PrivateMessageQueueWorker.php <==
<?php

namespace Drupal\private_message_queue\Plugin\QueueWorker;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\Core\Session\AccountInterface;
use Drupal\private_message\Entity\PrivateMessage;
use Drupal\private_message\Entity\PrivateMessageInterface;
use Drupal\private_message\Service\PrivateMessageServiceInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes queued private message threads.
 *
 * @QueueWorker(
 *   id = "private_message_queue",
 *   title = @Translation("Queue for creating private message threads."),
 *   cron = {"time" = 60}
 * )
 */
class PrivateMessageQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
   * The private message service.
   *
   * @var \Drupal\private_message\Service\PrivateMessageServiceInterface
   */
  private $privateMessage;

  /**
   * Creates a new \Drupal\private_message_queue\Plugin\QueueWorker\PrivateMessageThreadQueue.
   *
   * @param array $configuration
   *  A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\private_message\Service\PrivateMessageServiceInterface $private_message_service
   *   The private message service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, PrivateMessageServiceInterface $private_message_service) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->privateMessage = $private_message_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('private_message.service')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data) {
    $message = $this->createMessage($data['owner'], $data['message']);

    $this->createThread($message, $data['recipients'], $data['owner']);
  }

  /**
   * Create a new private message.
   *
   * @param \Drupal\Core\Session\AccountInterface $owner
   *   The message owner.
   * @param string $message_body
   *   The message body.
   * @param string $text_format
   *   (optional) The text format. Defaults to 'basic_html'.
   *
   * @return \Drupal\Core\Entity\EntityInterface|\Drupal\private_message\Entity\PrivateMessage
   *   The created message.
   */
  private function createMessage(AccountInterface $owner, $message_body, $text_format = 'basic_html') {
    $message = PrivateMessage::create();
    $message->setOwnerId($owner->id());
    $message->set('message', ['value' => strip_tags($message_body), 'format' => $text_format]);
    $message->save();

    return $message;
  }

  /**
   * Create a private message thread.
   *
   * @param \Drupal\private_message\Entity\PrivateMessageInterface $message
   *   A message to add.
   * @param \Drupal\user\UserInterface[] $members
   *   The thread members.
   * @param \Drupal\Core\Session\AccountInterface $owner
   *   The message owner.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  private function createThread(PrivateMessageInterface $message, array $members, AccountInterface $owner) {
    // Ensure that the message owner is added as a thread member.
    if (!in_array($owner, $members)) {
      $members[] = $owner;
    }

    /** @var \Drupal\private_message\Entity\PrivateMessageThreadInterface $thread */
    $thread = $this->privateMessage->getThreadForMembers($members);
    $thread->addMessage($message);
    $thread->save();
  }

}
